pub struct StyleContextSelectorMembershipV0 {
pub selector_name: String,
pub context_id: String,
pub context_kind: &'static str,
pub source_order: usize,
}Expand description
Selector membership edge from a selector to an enclosing context block.
Fields
selector_name: Stringcontext_id: Stringcontext_kind: &'static strsource_order: usizeTrait Implementations
Sourceimpl Clone for StyleContextSelectorMembershipV0
impl Clone for StyleContextSelectorMembershipV0
Sourcefn clone(&self) -> StyleContextSelectorMembershipV0
fn clone(&self) -> StyleContextSelectorMembershipV0
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Eq for StyleContextSelectorMembershipV0
Sourceimpl Ord for StyleContextSelectorMembershipV0
impl Ord for StyleContextSelectorMembershipV0
Sourcefn cmp(&self, other: &StyleContextSelectorMembershipV0) -> Ordering
fn cmp(&self, other: &StyleContextSelectorMembershipV0) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StyleContextSelectorMembershipV0
impl PartialEq for StyleContextSelectorMembershipV0
Sourcefn eq(&self, other: &StyleContextSelectorMembershipV0) -> bool
fn eq(&self, other: &StyleContextSelectorMembershipV0) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for StyleContextSelectorMembershipV0
impl PartialOrd for StyleContextSelectorMembershipV0
impl StructuralPartialEq for StyleContextSelectorMembershipV0